@@ -1,5 +1,5 @@
 #!/usr/bin/env python
-# pylint: disable=C0103,W0622
+# pylint: disable=W0622
 #
 # A library that provides a Python interface to the Telegram Bot API
 # Copyright (C) 2015-2021
@@ -18,11 +18,13 @@
 # You should have received a copy of the GNU Lesser Public License
 # along with this program.  If not, see [http://www.gnu.org/licenses/].
 """This module contains an object that represents a Telegram Chat."""
+import warnings
 from datetime import datetime
 from typing import TYPE_CHECKING, List, Optional, ClassVar, Union, Tuple, Any
 
 from telegram import ChatPhoto, TelegramObject, constants
 from telegram.utils.types import JSONDict, FileInput, ODVInput, DVInput
+from telegram.utils.deprecate import TelegramDeprecationWarning
 
 from .chatpermissions import ChatPermissions
 from .chatlocation import ChatLocation
@@ -32,6 +34,7 @@ if TYPE_CHECKING:
     from telegram import (
         Bot,
         ChatMember,
+        ChatInviteLink,
         Message,
         MessageId,
         ReplyMarkup,
@@ -78,12 +81,15 @@ class Chat(TelegramObject):
             Returned only in :meth:`telegram.Bot.get_chat`.
         bio (:obj:`str`, optional): Bio of the other party in a private chat. Returned only in
             :meth:`telegram.Bot.get_chat`.
+        has_private_forwards (:obj:`bool`, optional): :obj:`True`, if privacy settings of the other
+            party in the private chat allows to use ``tg://user?id=<user_id>`` links only in chats
+            with the user. Returned only in :meth:`telegram.Bot.get_chat`.
+
+            .. versionadded:: 13.9
         description (:obj:`str`, optional): Description, for groups, supergroups and channel chats.
             Returned only in :meth:`telegram.Bot.get_chat`.
-        invite_link (:obj:`str`, optional): Chat invite link, for groups, supergroups and channel
-            chats. Each administrator in a chat generates their own invite links, so the bot must
-            first generate the link using ``export_chat_invite_link()``. Returned only
-            in :meth:`telegram.Bot.get_chat`.
+        invite_link (:obj:`str`, optional): Primary invite link, for groups, supergroups and
+            channel. Returned only in :meth:`telegram.Bot.get_chat`.
         pinned_message (:class:`telegram.Message`, optional): The most recent pinned message
             (by sending date). Returned only in :meth:`telegram.Bot.get_chat`.
         permissions (:class:`telegram.ChatPermissions`): Optional. Default chat member permissions,
@@ -91,6 +97,15 @@ class Chat(TelegramObject):
         slow_mode_delay (:obj:`int`, optional): For supergroups, the minimum allowed delay between
             consecutive messages sent by each unprivileged user.
             Returned only in :meth:`telegram.Bot.get_chat`.
+        message_auto_delete_time (:obj:`int`, optional): The time after which all messages sent to
+            the chat will be automatically deleted; in seconds. Returned only in
+            :meth:`telegram.Bot.get_chat`.
+
+            .. versionadded:: 13.4
+        has_protected_content (:obj:`bool`, optional): :obj:`True`, if messages from the chat can't
+            be forwarded to other chats. Returned only in :meth:`telegram.Bot.get_chat`.
+
+            .. versionadded:: 13.9
         bot (:class:`telegram.Bot`, optional): The Bot to use for instance methods.
         sticker_set_name (:obj:`str`, optional): For supergroups, name of group sticker set.
             Returned only in :meth:`telegram.Bot.get_chat`.
@@ -113,8 +128,14 @@ class Chat(TelegramObject):
         photo (:class:`telegram.ChatPhoto`): Optional. Chat photo.
         bio (:obj:`str`): Optional. Bio of the other party in a private chat. Returned only in
             :meth:`telegram.Bot.get_chat`.
+        has_private_forwards (:obj:`bool`): Optional. :obj:`True`, if privacy settings of the other
+            party in the private chat allows to use ``tg://user?id=<user_id>`` links only in chats
+            with the user.
+
+            .. versionadded:: 13.9
         description (:obj:`str`): Optional. Description, for groups, supergroups and channel chats.
-        invite_link (:obj:`str`): Optional. Chat invite link, for supergroups and channel chats.
+        invite_link (:obj:`str`): Optional. Primary invite link, for groups, supergroups and
+            channel. Returned only in :meth:`telegram.Bot.get_chat`.
         pinned_message (:class:`telegram.Message`): Optional. The most recent pinned message
             (by sending date). Returned only in :meth:`telegram.Bot.get_chat`.
         permissions (:class:`telegram.ChatPermissions`): Optional. Default chat member permissions,
@@ -122,6 +143,15 @@ class Chat(TelegramObject):
         slow_mode_delay (:obj:`int`): Optional. For supergroups, the minimum allowed delay between
             consecutive messages sent by each unprivileged user. Returned only in
             :meth:`telegram.Bot.get_chat`.
+        message_auto_delete_time (:obj:`int`): Optional. The time after which all messages sent to
+            the chat will be automatically deleted; in seconds. Returned only in
+            :meth:`telegram.Bot.get_chat`.
+
+            .. versionadded:: 13.4
+        has_protected_content (:obj:`bool`): Optional. :obj:`True`, if messages from the chat can't
+            be forwarded to other chats.
+
+            .. versionadded:: 13.9
         sticker_set_name (:obj:`str`): Optional. For supergroups, name of Group sticker set.
         can_set_sticker_set (:obj:`bool`): Optional. :obj:`True`, if the bot can change group the
             sticker set.
@@ -133,6 +163,37 @@ class Chat(TelegramObject):
 
     """
 
+    __slots__ = (
+        'bio',
+        'id',
+        'type',
+        'last_name',
+        'bot',
+        'sticker_set_name',
+        'slow_mode_delay',
+        'location',
+        'first_name',
+        'permissions',
+        'invite_link',
+        'pinned_message',
+        'description',
+        'can_set_sticker_set',
+        'username',
+        'title',
+        'photo',
+        'linked_chat_id',
+        'all_members_are_administrators',
+        'message_auto_delete_time',
+        'has_protected_content',
+        'has_private_forwards',
+        '_id_attrs',
+    )
+
+    SENDER: ClassVar[str] = constants.CHAT_SENDER
+    """:const:`telegram.constants.CHAT_SENDER`
+
+    .. versionadded:: 13.5
+    """
     PRIVATE: ClassVar[str] = constants.CHAT_PRIVATE
     """:const:`telegram.constants.CHAT_PRIVATE`"""
     GROUP: ClassVar[str] = constants.CHAT_GROUP
@@ -162,10 +223,13 @@ class Chat(TelegramObject):
         bio: str = None,
         linked_chat_id: int = None,
         location: ChatLocation = None,
+        message_auto_delete_time: int = None,
+        has_private_forwards: bool = None,
+        has_protected_content: bool = None,
         **_kwargs: Any,
     ):
         # Required
-        self.id = int(id)
+        self.id = int(id)  # pylint: disable=C0103
         self.type = type
         # Optionals
         self.title = title
@@ -176,11 +240,16 @@ class Chat(TelegramObject):
         self.all_members_are_administrators = _kwargs.get('all_members_are_administrators')
         self.photo = photo
         self.bio = bio
+        self.has_private_forwards = has_private_forwards
         self.description = description
         self.invite_link = invite_link
         self.pinned_message = pinned_message
         self.permissions = permissions
         self.slow_mode_delay = slow_mode_delay
+        self.message_auto_delete_time = (
+            int(message_auto_delete_time) if message_auto_delete_time is not None else None
+        )
+        self.has_protected_content = has_protected_content
         self.sticker_set_name = sticker_set_name
         self.can_set_sticker_set = can_set_sticker_set
         self.linked_chat_id = linked_chat_id
@@ -210,14 +279,16 @@ class Chat(TelegramObject):
     @property
     def link(self) -> Optional[str]:
         """:obj:`str`: Convenience property. If the chat has a :attr:`username`, returns a t.me
-        link of the chat."""
+        link of the chat.
+        """
         if self.username:
             return f"https://t.me/{self.username}"
         return None
 
     @classmethod
-    def de_json(cls, data: JSONDict, bot: 'Bot') -> Optional['Chat']:
-        data = cls.parse_data(data)
+    def de_json(cls, data: Optional[JSONDict], bot: 'Bot') -> Optional['Chat']:
+        """See :meth:`telegram.TelegramObject.de_json`."""
+        data = cls._parse_data(data)
 
         if not data:
             return None
@@ -239,7 +310,7 @@ class Chat(TelegramObject):
         For the documentation of the arguments, please see :meth:`telegram.Bot.leave_chat`.
 
         Returns:
-            :obj:`bool` If the action was sent successfully.
+            :obj:`bool`: On success, :obj:`True` is returned.
 
         """
         return self.bot.leave_chat(
@@ -273,19 +344,37 @@ class Chat(TelegramObject):
 
     def get_members_count(
         self, timeout: ODVInput[float] = DEFAULT_NONE, api_kwargs: JSONDict = None
+    ) -> int:
+        """
+        Deprecated, use :func:`~telegram.Chat.get_member_count` instead.
+
+        .. deprecated:: 13.7
+        """
+        warnings.warn(
+            '`Chat.get_members_count` is deprecated. Use `Chat.get_member_count` instead.',
+            TelegramDeprecationWarning,
+            stacklevel=2,
+        )
+
+        return self.get_member_count(
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+        )
+
+    def get_member_count(
+        self, timeout: ODVInput[float] = DEFAULT_NONE, api_kwargs: JSONDict = None
     ) -> int:
         """Shortcut for::
 
-            bot.get_chat_members_count(update.effective_chat.id, *args, **kwargs)
+            bot.get_chat_member_count(update.effective_chat.id, *args, **kwargs)
 
         For the documentation of the arguments, please see
-        :meth:`telegram.Bot.get_chat_members_count`.
+        :meth:`telegram.Bot.get_chat_member_count`.
 
         Returns:
             :obj:`int`
-
         """
-        return self.bot.get_chat_members_count(
+        return self.bot.get_chat_member_count(
             chat_id=self.id,
             timeout=timeout,
             api_kwargs=api_kwargs,
@@ -320,29 +409,144 @@ class Chat(TelegramObject):
         timeout: ODVInput[float] = DEFAULT_NONE,
         until_date: Union[int, datetime] = None,
         api_kwargs: JSONDict = None,
+        revoke_messages: bool = None,
+    ) -> bool:
+        """
+        Deprecated, use :func:`~telegram.Chat.ban_member` instead.
+
+        .. deprecated:: 13.7
+        """
+        warnings.warn(
+            '`Chat.kick_member` is deprecated. Use `Chat.ban_member` instead.',
+            TelegramDeprecationWarning,
+            stacklevel=2,
+        )
+
+        return self.ban_member(
+            user_id=user_id,
+            timeout=timeout,
+            until_date=until_date,
+            api_kwargs=api_kwargs,
+            revoke_messages=revoke_messages,
+        )
+
+    def ban_member(
+        self,
+        user_id: Union[str, int],
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        until_date: Union[int, datetime] = None,
+        api_kwargs: JSONDict = None,
+        revoke_messages: bool = None,
     ) -> bool:
         """Shortcut for::
 
-            bot.kick_chat_member(update.effective_chat.id, *args, **kwargs)
+            bot.ban_chat_member(update.effective_chat.id, *args, **kwargs)
 
         For the documentation of the arguments, please see
-        :meth:`telegram.Bot.kick_chat_member`.
+        :meth:`telegram.Bot.ban_chat_member`.
 
         Returns:
-            :obj:`bool`: If the action was sent successfully.
-
-        Note:
-            This method will only work if the `All Members Are Admins` setting is off in the
-            target group. Otherwise members may only be removed by the group's creator or by the
-            member that added them.
-
+            :obj:`bool`: On success, :obj:`True` is returned.
         """
-        return self.bot.kick_chat_member(
+        return self.bot.ban_chat_member(
             chat_id=self.id,
             user_id=user_id,
             timeout=timeout,
             until_date=until_date,
             api_kwargs=api_kwargs,
+            revoke_messages=revoke_messages,
+        )
+
+    def ban_sender_chat(
+        self,
+        sender_chat_id: int,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
+        """Shortcut for::
+
+            bot.ban_chat_sender_chat(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.ban_chat_sender_chat`.
+
+        .. versionadded:: 13.9
+
+        Returns:
+            :obj:`bool`: On success, :obj:`True` is returned.
+
+        """
+        return self.bot.ban_chat_sender_chat(
+            chat_id=self.id, sender_chat_id=sender_chat_id, timeout=timeout, api_kwargs=api_kwargs
+        )
+
+    def ban_chat(
+        self,
+        chat_id: Union[str, int],
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
+        """Shortcut for::
+
+            bot.ban_chat_sender_chat(sender_chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.ban_chat_sender_chat`.
+
+        .. versionadded:: 13.9
+
+        Returns:
+            :obj:`bool`: On success, :obj:`True` is returned.
+
+        """
+        return self.bot.ban_chat_sender_chat(
+            chat_id=chat_id, sender_chat_id=self.id, timeout=timeout, api_kwargs=api_kwargs
+        )
+
+    def unban_sender_chat(
+        self,
+        sender_chat_id: int,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
+        """Shortcut for::
+
+            bot.unban_chat_sender_chat(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.unban_chat_sender_chat`.
+
+        .. versionadded:: 13.9
+
+        Returns:
+            :obj:`bool`: On success, :obj:`True` is returned.
+
+        """
+        return self.bot.unban_chat_sender_chat(
+            chat_id=self.id, sender_chat_id=sender_chat_id, timeout=timeout, api_kwargs=api_kwargs
+        )
+
+    def unban_chat(
+        self,
+        chat_id: Union[str, int],
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
+        """Shortcut for::
+
+            bot.unban_chat_sender_chat(sender_chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.unban_chat_sender_chat`.
+
+        .. versionadded:: 13.9
+
+        Returns:
+            :obj:`bool`: On success, :obj:`True` is returned.
+
+        """
+        return self.bot.unban_chat_sender_chat(
+            chat_id=chat_id, sender_chat_id=self.id, timeout=timeout, api_kwargs=api_kwargs
         )
 
     def unban_member(
@@ -359,7 +563,7 @@ class Chat(TelegramObject):
         For the documentation of the arguments, please see :meth:`telegram.Bot.unban_chat_member`.
 
         Returns:
-            :obj:`bool`: If the action was sent successfully.
+            :obj:`bool`: On success, :obj:`True` is returned.
 
         """
         return self.bot.unban_chat_member(
@@ -384,6 +588,8 @@ class Chat(TelegramObject):
         timeout: ODVInput[float] = DEFAULT_NONE,
         api_kwargs: JSONDict = None,
         is_anonymous: bool = None,
+        can_manage_chat: bool = None,
+        can_manage_voice_chats: bool = None,
     ) -> bool:
         """Shortcut for::
 
@@ -395,7 +601,7 @@ class Chat(TelegramObject):
         .. versionadded:: 13.2
 
         Returns:
-            :obj:`bool`: If the action was sent successfully.
+            :obj:`bool`: On success, :obj:`True` is returned.
 
         """
         return self.bot.promote_chat_member(
@@ -412,6 +618,8 @@ class Chat(TelegramObject):
             timeout=timeout,
             api_kwargs=api_kwargs,
             is_anonymous=is_anonymous,
+            can_manage_chat=can_manage_chat,
+            can_manage_voice_chats=can_manage_voice_chats,
         )
 
     def restrict_member(
@@ -432,7 +640,7 @@ class Chat(TelegramObject):
         .. versionadded:: 13.2
 
         Returns:
-            :obj:`bool`: If the action was sent successfully.
+            :obj:`bool`: On success, :obj:`True` is returned.
 
         """
         return self.bot.restrict_chat_member(
@@ -458,7 +666,7 @@ class Chat(TelegramObject):
         :meth:`telegram.Bot.set_chat_permissions`.
 
         Returns:
-            :obj:`bool`: If the action was sent successfully.
+            :obj:`bool`: On success, :obj:`True` is returned.
 
         """
         return self.bot.set_chat_permissions(
@@ -483,7 +691,7 @@ class Chat(TelegramObject):
         :meth:`telegram.Bot.set_chat_administrator_custom_title`.
 
         Returns:
-        :obj:`bool`: If the action was sent successfully.
+            :obj:`bool`: On success, :obj:`True` is returned.
 
         """
         return self.bot.set_chat_administrator_custom_title(
@@ -496,7 +704,7 @@ class Chat(TelegramObject):
 
     def pin_message(
         self,
-        message_id: Union[str, int],
+        message_id: int,
         disable_notification: ODVInput[bool] = DEFAULT_NONE,
         timeout: ODVInput[float] = DEFAULT_NONE,
         api_kwargs: JSONDict = None,
@@ -526,7 +734,7 @@ class Chat(TelegramObject):
         self,
         timeout: ODVInput[float] = DEFAULT_NONE,
         api_kwargs: JSONDict = None,
-        message_id: Union[str, int] = None,
+        message_id: int = None,
     ) -> bool:
         """Shortcut for::
 
@@ -578,7 +786,7 @@ class Chat(TelegramObject):
         parse_mode: ODVInput[str] = DEFAULT_NONE,
         disable_web_page_preview: ODVInput[bool] = DEFAULT_NONE,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
         api_kwargs: JSONDict = None,
@@ -615,7 +823,7 @@ class Chat(TelegramObject):
             Union['InputMediaAudio', 'InputMediaDocument', 'InputMediaPhoto', 'InputMediaVideo']
         ],
         disable_notification: ODVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         timeout: DVInput[float] = DEFAULT_20,
         api_kwargs: JSONDict = None,
         allow_sending_without_reply: ODVInput[bool] = DEFAULT_NONE,
@@ -627,7 +835,7 @@ class Chat(TelegramObject):
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_media_group`.
 
         Returns:
-            List[:class:`telegram.Message`:] On success, instance representing the message posted.
+            List[:class:`telegram.Message`]: On success, instance representing the message posted.
 
         """
         return self.bot.send_media_group(
@@ -671,7 +879,7 @@ class Chat(TelegramObject):
         photo: Union[FileInput, 'PhotoSize'],
         caption: str = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
@@ -711,7 +919,7 @@ class Chat(TelegramObject):
         first_name: str = None,
         last_name: str = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
         contact: 'Contact' = None,
@@ -752,7 +960,7 @@ class Chat(TelegramObject):
         title: str = None,
         caption: str = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
@@ -797,7 +1005,7 @@ class Chat(TelegramObject):
         filename: str = None,
         caption: str = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
@@ -837,7 +1045,7 @@ class Chat(TelegramObject):
     def send_dice(
         self,
         disable_notification: ODVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
         emoji: str = None,
@@ -869,7 +1077,7 @@ class Chat(TelegramObject):
         self,
         game_short_name: str,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'InlineKeyboardMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
         api_kwargs: JSONDict = None,
@@ -902,9 +1110,9 @@ class Chat(TelegramObject):
         description: str,
         payload: str,
         provider_token: str,
-        start_parameter: str,
         currency: str,
         prices: List['LabeledPrice'],
+        start_parameter: str = None,
         photo_url: str = None,
         photo_size: int = None,
         photo_width: int = None,
@@ -915,7 +1123,7 @@ class Chat(TelegramObject):
         need_shipping_address: bool = None,
         is_flexible: bool = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'InlineKeyboardMarkup' = None,
         provider_data: Union[str, object] = None,
         send_phone_number_to_provider: bool = None,
@@ -923,6 +1131,8 @@ class Chat(TelegramObject):
         timeout: ODVInput[float] = DEFAULT_NONE,
         api_kwargs: JSONDict = None,
         allow_sending_without_reply: ODVInput[bool] = DEFAULT_NONE,
+        max_tip_amount: int = None,
+        suggested_tip_amounts: List[int] = None,
     ) -> 'Message':
         """Shortcut for::
 
@@ -930,6 +1140,14 @@ class Chat(TelegramObject):
 
         For the documentation of the arguments, please see :meth:`telegram.Bot.send_invoice`.
 
+        Warning:
+            As of API 5.2 :attr:`start_parameter` is an optional argument and therefore the order
+            of the arguments had to be changed. Use keyword arguments to make sure that the
+            arguments are passed correctly.
+
+        .. versionchanged:: 13.5
+            As of Bot API 5.2, the parameter :attr:`start_parameter` is optional.
+
         Returns:
             :class:`telegram.Message`: On success, instance representing the message posted.
 
@@ -940,9 +1158,9 @@ class Chat(TelegramObject):
             description=description,
             payload=payload,
             provider_token=provider_token,
-            start_parameter=start_parameter,
             currency=currency,
             prices=prices,
+            start_parameter=start_parameter,
             photo_url=photo_url,
             photo_size=photo_size,
             photo_width=photo_width,
@@ -961,6 +1179,8 @@ class Chat(TelegramObject):
             timeout=timeout,
             api_kwargs=api_kwargs,
             allow_sending_without_reply=allow_sending_without_reply,
+            max_tip_amount=max_tip_amount,
+            suggested_tip_amounts=suggested_tip_amounts,
         )
 
     def send_location(
@@ -968,7 +1188,7 @@ class Chat(TelegramObject):
         latitude: float = None,
         longitude: float = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
         location: 'Location' = None,
@@ -1016,7 +1236,7 @@ class Chat(TelegramObject):
         caption: str = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         api_kwargs: JSONDict = None,
@@ -1057,7 +1277,7 @@ class Chat(TelegramObject):
         self,
         sticker: Union[FileInput, 'Sticker'],
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         api_kwargs: JSONDict = None,
@@ -1092,7 +1312,7 @@ class Chat(TelegramObject):
         address: str = None,
         foursquare_id: str = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
         venue: 'Venue' = None,
@@ -1137,7 +1357,7 @@ class Chat(TelegramObject):
         duration: int = None,
         caption: str = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         width: int = None,
@@ -1186,7 +1406,7 @@ class Chat(TelegramObject):
         duration: int = None,
         length: int = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         thumb: FileInput = None,
@@ -1225,7 +1445,7 @@ class Chat(TelegramObject):
         duration: int = None,
         caption: str = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: DVInput[float] = DEFAULT_20,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
@@ -1271,7 +1491,7 @@ class Chat(TelegramObject):
         correct_option_id: int = None,
         is_closed: bool = None,
         disable_notification: ODVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
         explanation: str = None,
@@ -1317,12 +1537,12 @@ class Chat(TelegramObject):
     def send_copy(
         self,
         from_chat_id: Union[str, int],
-        message_id: Union[str, int],
+        message_id: int,
         caption: str = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
         caption_entities: Union[Tuple['MessageEntity', ...], List['MessageEntity']] = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         allow_sending_without_reply: DVInput[bool] = DEFAULT_NONE,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
@@ -1356,12 +1576,12 @@ class Chat(TelegramObject):
     def copy_message(
         self,
         chat_id: Union[int, str],
-        message_id: Union[str, int],
+        message_id: int,
         caption: str = None,
         parse_mode: ODVInput[str] = DEFAULT_NONE,
         caption_entities: Union[Tuple['MessageEntity', ...], List['MessageEntity']] = None,
         disable_notification: DVInput[bool] = DEFAULT_NONE,
-        reply_to_message_id: Union[int, str] = None,
+        reply_to_message_id: int = None,
         allow_sending_without_reply: DVInput[bool] = DEFAULT_NONE,
         reply_markup: 'ReplyMarkup' = None,
         timeout: ODVInput[float] = DEFAULT_NONE,
@@ -1391,3 +1611,167 @@ class Chat(TelegramObject):
             timeout=timeout,
             api_kwargs=api_kwargs,
         )
+
+    def export_invite_link(
+        self,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> str:
+        """Shortcut for::
+
+            bot.export_chat_invite_link(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.export_chat_invite_link`.
+
+        .. versionadded:: 13.4
+
+        Returns:
+            :obj:`str`: New invite link on success.
+
+        """
+        return self.bot.export_chat_invite_link(
+            chat_id=self.id, timeout=timeout, api_kwargs=api_kwargs
+        )
+
+    def create_invite_link(
+        self,
+        expire_date: Union[int, datetime] = None,
+        member_limit: int = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+        name: str = None,
+        creates_join_request: bool = None,
+    ) -> 'ChatInviteLink':
+        """Shortcut for::
+
+            bot.create_chat_invite_link(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.create_chat_invite_link`.
+
+        .. versionadded:: 13.4
+
+        .. versionchanged:: 13.8
+           Edited signature according to the changes of
+           :meth:`telegram.Bot.create_chat_invite_link`.
+
+        Returns:
+            :class:`telegram.ChatInviteLink`
+
+        """
+        return self.bot.create_chat_invite_link(
+            chat_id=self.id,
+            expire_date=expire_date,
+            member_limit=member_limit,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+            name=name,
+            creates_join_request=creates_join_request,
+        )
+
+    def edit_invite_link(
+        self,
+        invite_link: str,
+        expire_date: Union[int, datetime] = None,
+        member_limit: int = None,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+        name: str = None,
+        creates_join_request: bool = None,
+    ) -> 'ChatInviteLink':
+        """Shortcut for::
+
+            bot.edit_chat_invite_link(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.edit_chat_invite_link`.
+
+        .. versionadded:: 13.4
+
+        .. versionchanged:: 13.8
+           Edited signature according to the changes of :meth:`telegram.Bot.edit_chat_invite_link`.
+
+        Returns:
+            :class:`telegram.ChatInviteLink`
+
+        """
+        return self.bot.edit_chat_invite_link(
+            chat_id=self.id,
+            invite_link=invite_link,
+            expire_date=expire_date,
+            member_limit=member_limit,
+            timeout=timeout,
+            api_kwargs=api_kwargs,
+            name=name,
+            creates_join_request=creates_join_request,
+        )
+
+    def revoke_invite_link(
+        self,
+        invite_link: str,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> 'ChatInviteLink':
+        """Shortcut for::
+
+            bot.revoke_chat_invite_link(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.revoke_chat_invite_link`.
+
+        .. versionadded:: 13.4
+
+        Returns:
+            :class:`telegram.ChatInviteLink`
+
+        """
+        return self.bot.revoke_chat_invite_link(
+            chat_id=self.id, invite_link=invite_link, timeout=timeout, api_kwargs=api_kwargs
+        )
+
+    def approve_join_request(
+        self,
+        user_id: int,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
+        """Shortcut for::
+
+            bot.approve_chat_join_request(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.approve_chat_join_request`.
+
+        .. versionadded:: 13.8
+
+        Returns:
+            :obj:`bool`: On success, :obj:`True` is returned.
+
+        """
+        return self.bot.approve_chat_join_request(
+            chat_id=self.id, user_id=user_id, timeout=timeout, api_kwargs=api_kwargs
+        )
+
+    def decline_join_request(
+        self,
+        user_id: int,
+        timeout: ODVInput[float] = DEFAULT_NONE,
+        api_kwargs: JSONDict = None,
+    ) -> bool:
+        """Shortcut for::
+
+            bot.decline_chat_join_request(chat_id=update.effective_chat.id, *args, **kwargs)
+
+        For the documentation of the arguments, please see
+        :meth:`telegram.Bot.decline_chat_join_request`.
+
+        .. versionadded:: 13.8
+
+        Returns:
+            :obj:`bool`: On success, :obj:`True` is returned.
+
+        """
+        return self.bot.decline_chat_join_request(
+            chat_id=self.id, user_id=user_id, timeout=timeout, api_kwargs=api_kwargs
+        )
