@@ -37,7 +37,8 @@ from telegram.ext import (
     InlineQueryHandler,
 )
 from telegram.ext.utils.promise import Promise
-from telegram.utils.types import ConversationDict
+from telegram.ext.utils.types import ConversationDict
+from telegram.ext.utils.types import CCT
 
 if TYPE_CHECKING:
     from telegram.ext import Dispatcher, Job
@@ -45,6 +46,9 @@ CheckUpdateType = Optional[Tuple[Tuple[int, ...], Handler, object]]
 
 
 class _ConversationTimeoutContext:
+    # '__dict__' is not included since this a private class
+    __slots__ = ('conversation_key', 'update', 'dispatcher', 'callback_context')
+
     def __init__(
         self,
         conversation_key: Tuple[int, ...],
@@ -58,7 +62,7 @@ class _ConversationTimeoutContext:
         self.callback_context = callback_context
 
 
-class ConversationHandler(Handler[Update]):
+class ConversationHandler(Handler[Update, CCT]):
     """
     A handler to hold a conversation with a single or multiple users through Telegram updates by
     managing four collections of other handlers.
@@ -173,33 +177,8 @@ class ConversationHandler(Handler[Update]):
         ValueError
 
     Attributes:
-        entry_points (List[:class:`telegram.ext.Handler`]): A list of ``Handler`` objects that can
-            trigger the start of the conversation.
-        states (Dict[:obj:`object`, List[:class:`telegram.ext.Handler`]]): A :obj:`dict` that
-            defines the different states of conversation a user can be in and one or more
-            associated ``Handler`` objects that should be used in that state.
-        fallbacks (List[:class:`telegram.ext.Handler`]): A list of handlers that might be used if
-            the user is in a conversation, but every handler for their current state returned
-            :obj:`False` on :attr:`check_update`.
-        allow_reentry (:obj:`bool`): Determines if a user can restart a conversation with
-            an entry point.
-        per_chat (:obj:`bool`): If the conversationkey should contain the Chat's ID.
-        per_user (:obj:`bool`): If the conversationkey should contain the User's ID.
-        per_message (:obj:`bool`): If the conversationkey should contain the Message's
-            ID.
-        conversation_timeout (:obj:`float` | :obj:`datetime.timedelta`): Optional. When this
-            handler is inactive more than this timeout (in seconds), it will be automatically
-            ended. If this value is 0 (default), there will be no timeout. When it's triggered, the
-            last received update and the corresponding ``context`` will be handled by ALL the
-            handler's who's :attr:`check_update` method returns :obj:`True` that are in the state
-            :attr:`ConversationHandler.TIMEOUT`.
-        name (:obj:`str`): Optional. The name for this conversationhandler. Required for
-            persistence
         persistent (:obj:`bool`): Optional. If the conversations dict for this handler should be
             saved. Name is required and persistence has to be set in :class:`telegram.ext.Updater`
-        map_to_parent (Dict[:obj:`object`, :obj:`object`]): Optional. A :obj:`dict` that can be
-            used to instruct a nested conversationhandler to transition into a mapped state on
-            its parent conversationhandler in place of a specified nested state.
         run_async (:obj:`bool`): If :obj:`True`, will override the
             :attr:`Handler.run_async` setting of all internal handlers on initialization.
 
@@ -207,6 +186,26 @@ class ConversationHandler(Handler[Update]):
 
     """
 
+    __slots__ = (
+        '_entry_points',
+        '_states',
+        '_fallbacks',
+        '_allow_reentry',
+        '_per_user',
+        '_per_chat',
+        '_per_message',
+        '_conversation_timeout',
+        '_name',
+        'persistent',
+        '_persistence',
+        '_map_to_parent',
+        'timeout_jobs',
+        '_timeout_jobs_lock',
+        '_conversations',
+        '_conversations_lock',
+        'logger',
+    )
+
     END: ClassVar[int] = -1
     """:obj:`int`: Used as a constant to return when a conversation is ended."""
     TIMEOUT: ClassVar[int] = -2
@@ -217,9 +216,9 @@ class ConversationHandler(Handler[Update]):
     # pylint: disable=W0231
     def __init__(
         self,
-        entry_points: List[Handler],
-        states: Dict[object, List[Handler]],
-        fallbacks: List[Handler],
+        entry_points: List[Handler[Update, CCT]],
+        states: Dict[object, List[Handler[Update, CCT]]],
+        fallbacks: List[Handler[Update, CCT]],
         allow_reentry: bool = False,
         per_chat: bool = True,
         per_user: bool = True,
@@ -316,6 +315,9 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def entry_points(self) -> List[Handler]:
+        """List[:class:`telegram.ext.Handler`]: A list of ``Handler`` objects that can trigger the
+        start of the conversation.
+        """
         return self._entry_points
 
     @entry_points.setter
@@ -324,6 +326,10 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def states(self) -> Dict[object, List[Handler]]:
+        """Dict[:obj:`object`, List[:class:`telegram.ext.Handler`]]: A :obj:`dict` that
+        defines the different states of conversation a user can be in and one or more
+        associated ``Handler`` objects that should be used in that state.
+        """
         return self._states
 
     @states.setter
@@ -332,6 +338,10 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def fallbacks(self) -> List[Handler]:
+        """List[:class:`telegram.ext.Handler`]: A list of handlers that might be used if
+        the user is in a conversation, but every handler for their current state returned
+        :obj:`False` on :attr:`check_update`.
+        """
         return self._fallbacks
 
     @fallbacks.setter
@@ -340,6 +350,7 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def allow_reentry(self) -> bool:
+        """:obj:`bool`: Determines if a user can restart a conversation with an entry point."""
         return self._allow_reentry
 
     @allow_reentry.setter
@@ -348,6 +359,7 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def per_user(self) -> bool:
+        """:obj:`bool`: If the conversation key should contain the User's ID."""
         return self._per_user
 
     @per_user.setter
@@ -356,6 +368,7 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def per_chat(self) -> bool:
+        """:obj:`bool`: If the conversation key should contain the Chat's ID."""
         return self._per_chat
 
     @per_chat.setter
@@ -364,6 +377,7 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def per_message(self) -> bool:
+        """:obj:`bool`: If the conversation key should contain the message's ID."""
         return self._per_message
 
     @per_message.setter
@@ -374,16 +388,21 @@ class ConversationHandler(Handler[Update]):
     def conversation_timeout(
         self,
     ) -> Optional[Union[float, datetime.timedelta]]:
+        """:obj:`float` | :obj:`datetime.timedelta`: Optional. When this
+        handler is inactive more than this timeout (in seconds), it will be automatically
+        ended.
+        """
         return self._conversation_timeout
 
     @conversation_timeout.setter
     def conversation_timeout(self, value: object) -> NoReturn:
         raise ValueError(
-            'You can not assign a new value to conversation_timeout after ' 'initialization.'
+            'You can not assign a new value to conversation_timeout after initialization.'
         )
 
     @property
     def name(self) -> Optional[str]:
+        """:obj:`str`: Optional. The name for this :class:`ConversationHandler`."""
         return self._name
 
     @name.setter
@@ -392,6 +411,10 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def map_to_parent(self) -> Optional[Dict[object, object]]:
+        """Dict[:obj:`object`, :obj:`object`]: Optional. A :obj:`dict` that can be
+        used to instruct a nested :class:`ConversationHandler` to transition into a mapped state on
+        its parent :class:`ConversationHandler` in place of a specified nested state.
+        """
         return self._map_to_parent
 
     @map_to_parent.setter
@@ -400,6 +423,7 @@ class ConversationHandler(Handler[Update]):
 
     @property
     def persistence(self) -> Optional[BasePersistence]:
+        """The persistence class as provided by the :class:`Dispatcher`."""
         return self._persistence
 
     @persistence.setter
@@ -412,7 +436,7 @@ class ConversationHandler(Handler[Update]):
                     handler.persistence = self.persistence
 
     @property
-    def conversations(self) -> ConversationDict:
+    def conversations(self) -> ConversationDict:  # skipcq: PY-D0003
         return self._conversations
 
     @conversations.setter
@@ -518,7 +542,7 @@ class ConversationHandler(Handler[Update]):
             # check if promise is finished or not
             if state[1].done.wait(0):
                 res = self._resolve_promise(state)
-                self.update_state(res, key)
+                self._update_state(res, key)
                 with self._conversations_lock:
                     state = self.conversations.get(key)
 
@@ -627,19 +651,19 @@ class ConversationHandler(Handler[Update]):
                     )
 
         if isinstance(self.map_to_parent, dict) and new_state in self.map_to_parent:
-            self.update_state(self.END, conversation_key)
+            self._update_state(self.END, conversation_key)
             if raise_dp_handler_stop:
                 raise DispatcherHandlerStop(self.map_to_parent.get(new_state))
             return self.map_to_parent.get(new_state)
 
-        self.update_state(new_state, conversation_key)
+        self._update_state(new_state, conversation_key)
         if raise_dp_handler_stop:
             # Don't pass the new state here. If we're in a nested conversation, the parent is
             # expecting None as return value.
             raise DispatcherHandlerStop()
         return None
 
-    def update_state(self, new_state: object, key: Tuple[int, ...]) -> None:
+    def _update_state(self, new_state: object, key: Tuple[int, ...]) -> None:
         if new_state == self.END:
             with self._conversations_lock:
                 if key in self.conversations:
@@ -698,4 +722,4 @@ class ConversationHandler(Handler[Update]):
                         'ConversationHandler has no effect. Ignoring.'
                     )
 
-        self.update_state(self.END, ctxt.conversation_key)
+        self._update_state(self.END, ctxt.conversation_key)
